summaryrefslogtreecommitdiff
path: root/fitz/fitz.h
diff options
context:
space:
mode:
authorTor Andersson <tor.andersson@artifex.com>2012-01-27 14:16:58 +0100
committerTor Andersson <tor.andersson@artifex.com>2012-01-27 14:18:22 +0100
commit03b276d3f2db3feecb522f101e0da065c4af53d4 (patch)
tree512eabad1f8b5516003c254c5cf10439ba79a98c /fitz/fitz.h
parent40575c42719566f3585c5aa67129a8a5b7285aa7 (diff)
downloadmupdf-03b276d3f2db3feecb522f101e0da065c4af53d4.tar.xz
Rename pdf_xref type to pdf_document.
Diffstat (limited to 'fitz/fitz.h')
-rw-r--r--fitz/fitz.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/fitz/fitz.h b/fitz/fitz.h
index 49db7dc2..e156cb27 100644
--- a/fitz/fitz.h
+++ b/fitz/fitz.h
@@ -641,7 +641,7 @@ fz_obj *fz_new_int(fz_context *ctx, int i);
fz_obj *fz_new_real(fz_context *ctx, float f);
fz_obj *fz_new_name(fz_context *ctx, char *str);
fz_obj *fz_new_string(fz_context *ctx, char *str, int len);
-fz_obj *fz_new_indirect(fz_context *ctx, int num, int gen, void *xref);
+fz_obj *fz_new_indirect(fz_context *ctx, int num, int gen, void *doc);
fz_obj *fz_new_array(fz_context *ctx, int initialcap);
fz_obj *fz_new_dict(fz_context *ctx, int initialcap);
@@ -704,7 +704,7 @@ void fz_debug_obj(fz_obj *obj);
void fz_debug_ref(fz_obj *obj);
void fz_set_str_len(fz_obj *obj, int newlen); /* private */
-void *fz_get_indirect_xref(fz_obj *obj); /* private */
+void *fz_get_indirect_document(fz_obj *obj); /* private */
/*
* Data buffers.
@@ -1067,8 +1067,8 @@ struct fz_font_s
fz_buffer **t3procs; /* has 256 entries if used */
float *t3widths; /* has 256 entries if used */
char *t3flags; /* has 256 entries if used */
- void *t3xref; /* a pdf_xref for the callback */
- void (*t3run)(void *xref, fz_obj *resources, fz_buffer *contents,
+ void *t3doc; /* a pdf_document for the callback */
+ void (*t3run)(void *doc, fz_obj *resources, fz_buffer *contents,
struct fz_device_s *dev, fz_matrix ctm, void *gstate);
fz_rect bbox; /* font bbox is used only for t3 fonts */